@@ -80,6 +80,8 @@ class NavParser:
             self.read_file(nmea)
         else:
             self.read_string(nmea)
+        self.most_recent = max(self._points, key=lambda s: self._points[s].get_timestamp())
+
 
     @staticmethod
     def get_final_lat_long(lat_before_conversion, long_before_conversion, lat_dir, long_dir) -> Tuple[float, float]:
@@ -146,6 +148,8 @@ class NavParser:
 
             self._points[lat, long].set_speed_kmh(speed_kmh)
             self._points[lat, long].set_timestamp(timestamp)
+            if timestamp > self._points[self.most_recent].get_timestamp():
+                self.most_recent = (lat, long)
 
         if lat is None or long is None:
             return
@@ -161,12 +165,11 @@ class NavParser:
     def remove_bad_points(self):
         self._points = {k: v for k, v in self._points.items() if v.has_all_data()}
 
-    def get_points(self) -> dict:  # getter function
+    def get_points(self) -> dict:
         return self._points
 
     def get_most_accurate_point(self) -> NavRowData:
         return max(self._points, key=lambda s: self._points[s].get_satellites_count())
 
-    def get_most_recent_points(self, num_of_points=1):
-        coords = sorted(self._points, key=lambda s: self._points[s].get_timestamp(), reverse=True)[:num_of_points]
-        return [self._points[c] for c in coords]
+    def get_most_recent_point(self):
+        return self._points[self.most_recent]
